@@ -5,7 +5,6 @@ import java.net.URL;
 import java.nio.charset.Charset;
 
 import org.yaml.snakeyaml.DumperOptions;
-import org.yaml.snakeyaml.DumperOptions.FlowStyle;
 
 import com.fasterxml.jackson.core.*;
 import com.fasterxml.jackson.core.format.InputAccessor;
@@ -54,9 +53,7 @@ public class YAMLFactory extends JsonFactory
     /**********************************************************************
      */
 
-    protected transient DumperOptions _outputOptions;
-
-    protected Integer[] _version;
+    protected DumperOptions.Version _version;
     
     /**
      * Default constructor used to create factory instances.
@@ -75,9 +72,11 @@ public class YAMLFactory extends JsonFactory
         super(oc);
         _yamlParserFeatures = DEFAULT_YAML_PARSER_FEATURE_FLAGS;
         _yamlGeneratorFeatures = DEFAULT_YAML_GENERATOR_FEATURE_FLAGS;
-        _outputOptions = _defaultOptions();
-        DumperOptions.Version version = _outputOptions.getVersion();
-        _version = (version == null) ? null : version.getArray();
+        /* 26-Jul-2013, tatu: Seems like we should force output as 1.1 but
+         *   that adds version declaration which looks ugly...
+         */
+        //_version = DumperOptions.Version.V1_1;
+        _version = null;
     }
 
     /**
@@ -86,22 +85,10 @@ public class YAMLFactory extends JsonFactory
     public YAMLFactory(YAMLFactory src, ObjectCodec oc)
     {
         super(src, oc);
-        _outputOptions = src._outputOptions;
         _version = src._version;
         _yamlParserFeatures = src._yamlParserFeatures;
         _yamlGeneratorFeatures = src._yamlGeneratorFeatures;
     }
-    
-    private static DumperOptions _defaultOptions()
-    {
-        DumperOptions opt = new DumperOptions();
-        // would we want canonical?
-        opt.setCanonical(false);
-        // if not, MUST specify flow styles
-        opt.setDefaultFlowStyle(FlowStyle.BLOCK);
-        return opt;
-        
-    }
 
     @Override
     public YAMLFactory copy()
@@ -123,8 +110,6 @@ public class YAMLFactory extends JsonFactory
      */
     @Override
     protected Object readResolve() {
-        // this is transient, need to explicitly recreate:
-        _outputOptions = _defaultOptions();
         return new YAMLFactory(this, _objectCodec);
     }
 
@@ -138,6 +123,16 @@ public class YAMLFactory extends JsonFactory
     public Version version() {
         return PackageVersion.VERSION;
     }
+
+    /*
+    /**********************************************************
+    /* Capability introspection
+    /**********************************************************
+     */
+
+    // No, we can't make use of char[] optimizations
+    @Override
+    public boolean canUseCharArrays() { return false; }
     
     /*
     /**********************************************************
@@ -287,22 +282,13 @@ public class YAMLFactory extends JsonFactory
      */
 
     @Override
-    public YAMLParser createParser(String content)
-        throws IOException, JsonParseException
-    {
-        Reader r = new StringReader(content);
-        IOContext ctxt = _createContext(r, true); // true->own, can close
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            r = _inputDecorator.decorate(ctxt, r);
-        }
-        return _createParser(r, ctxt);
+    public YAMLParser createParser(String content) throws IOException {
+        return createParser(new StringReader(content));
     }
-
+    
     @SuppressWarnings("resource")
     @Override
-    public YAMLParser createParser(File f)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(File f) throws IOException
     {
         IOContext ctxt = _createContext(f, true);
         InputStream in = new FileInputStream(f);
@@ -313,9 +299,9 @@ public class YAMLFactory extends JsonFactory
         return _createParser(in, ctxt);
     }
     
+    @SuppressWarnings("resource")
     @Override
-    public YAMLParser createParser(URL url)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(URL url) throws IOException
     {
         IOContext ctxt = _createContext(url, true);
         InputStream in = _optimizedStreamFromURL(url);
@@ -326,9 +312,9 @@ public class YAMLFactory extends JsonFactory
         return _createParser(in, ctxt);
     }
 
+    @SuppressWarnings("resource")
     @Override
-    public YAMLParser createParser(InputStream in)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(InputStream in) throws IOException
     {
         IOContext ctxt = _createContext(in, false);
         // [JACKSON-512]: allow wrapping with InputDecorator
@@ -338,9 +324,9 @@ public class YAMLFactory extends JsonFactory
         return _createParser(in, ctxt);
     }
 
+    @SuppressWarnings("resource")
     @Override
-    public JsonParser createParser(Reader r)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(Reader r) throws IOException
     {
         IOContext ctxt = _createContext(r, false);
         if (_inputDecorator != null) {
@@ -349,9 +335,19 @@ public class YAMLFactory extends JsonFactory
         return _createParser(r, ctxt);
     }
 
+    @Override // since 2.4
+    public YAMLParser createParser(char[] data) throws IOException {
+        return createParser(new CharArrayReader(data, 0, data.length));
+    }
+    
+    @Override // since 2.4
+    public YAMLParser createParser(char[] data, int offset, int len) throws IOException {
+        return createParser(new CharArrayReader(data, offset, len));
+    }
+    
+    @SuppressWarnings("resource")
     @Override
-    public YAMLParser createParser(byte[] data)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(byte[] data) throws IOException
     {
         IOContext ctxt = _createContext(data, true);
         // [JACKSON-512]: allow wrapping with InputDecorator
@@ -363,10 +359,10 @@ public class YAMLFactory extends JsonFactory
         }
         return _createParser(data, 0, data.length, ctxt);
     }
-    
+
+    @SuppressWarnings("resource")
     @Override
-    public YAMLParser createParser(byte[] data, int offset, int len)
-        throws IOException, JsonParseException
+    public YAMLParser createParser(byte[] data, int offset, int len) throws IOException
     {
         IOContext ctxt = _createContext(data, true);
         // [JACKSON-512]: allow wrapping with InputDecorator
@@ -379,118 +375,13 @@ public class YAMLFactory extends JsonFactory
         return _createParser(data, offset, len, ctxt);
     }
     
-    /*
-    /**********************************************************
-    /* Overridden parser factory methods (2.0 and prior)
-    /**********************************************************
-     */
-
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(String content)
-        throws IOException, JsonParseException
-    {
-        Reader r = new StringReader(content);
-        IOContext ctxt = _createContext(r, true); // true->own, can close
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            r = _inputDecorator.decorate(ctxt, r);
-        }
-        return _createParser(r, ctxt);
-    }
-
-    @SuppressWarnings("resource")
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(File f)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(f, true);
-        InputStream in = new FileInputStream(f);
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            in = _inputDecorator.decorate(ctxt, in);
-        }
-        return _createParser(in, ctxt);
-    }
-    
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(URL url)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(url, true);
-        InputStream in = _optimizedStreamFromURL(url);
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            in = _inputDecorator.decorate(ctxt, in);
-        }
-        return _createParser(in, ctxt);
-    }
-
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(InputStream in)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(in, false);
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            in = _inputDecorator.decorate(ctxt, in);
-        }
-        return _createParser(in, ctxt);
-    }
-
-    @Deprecated
-    @Override
-    public JsonParser createJsonParser(Reader r)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(r, false);
-        if (_inputDecorator != null) {
-            r = _inputDecorator.decorate(ctxt, r);
-        }
-        return _createParser(r, ctxt);
-    }
-
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(byte[] data)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(data, true);
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            InputStream in = _inputDecorator.decorate(ctxt, data, 0, data.length);
-            if (in != null) {
-                return _createParser(in, ctxt);
-            }
-        }
-        return _createParser(data, 0, data.length, ctxt);
-    }
-    
-    @Deprecated
-    @Override
-    public YAMLParser createJsonParser(byte[] data, int offset, int len)
-        throws IOException, JsonParseException
-    {
-        IOContext ctxt = _createContext(data, true);
-        // [JACKSON-512]: allow wrapping with InputDecorator
-        if (_inputDecorator != null) {
-            InputStream in = _inputDecorator.decorate(ctxt, data, offset, len);
-            if (in != null) {
-                return _createParser(in, ctxt);
-            }
-        }
-        return _createParser(data, offset, len, ctxt);
-    }
-
     /*
     /**********************************************************
     /* Overridden generator factory methods (2.1)
     /**********************************************************
      */
 
+    @SuppressWarnings("resource")
     @Override
     public YAMLGenerator createGenerator(OutputStream out, JsonEncoding enc) throws IOException
     {
@@ -503,6 +394,7 @@ public class YAMLFactory extends JsonFactory
         return _createGenerator(_createWriter(out, JsonEncoding.UTF8, ctxt), ctxt);
     }
 
+    @SuppressWarnings("resource")
     @Override
     public YAMLGenerator createGenerator(OutputStream out) throws IOException
     {
@@ -515,6 +407,7 @@ public class YAMLFactory extends JsonFactory
         return _createGenerator(_createWriter(out, JsonEncoding.UTF8, ctxt), ctxt);
     }
     
+    @SuppressWarnings("resource")
     @Override
     public YAMLGenerator createGenerator(Writer out) throws IOException
     {
@@ -525,31 +418,7 @@ public class YAMLFactory extends JsonFactory
         }
         return _createGenerator(out, ctxt);
     }
-    
-    /*
-    /**********************************************************
-    /* Overridden generator factory methods (2.0 and before)
-    /**********************************************************
-     */
 
-    @Deprecated
-    @Override
-    public YAMLGenerator createJsonGenerator(OutputStream out, JsonEncoding enc) throws IOException {
-        return createGenerator(out, enc);
-    }
-
-    @Deprecated
-    @Override
-    public YAMLGenerator createJsonGenerator(OutputStream out) throws IOException {
-        return createGenerator(out);
-    }
-
-    @Deprecated
-    @Override
-    public YAMLGenerator createJsonGenerator(Writer out) throws IOException {
-        return createGenerator(out);
-    }
-    
     /*
     /******************************************************
     /* Overridden internal factory methods
@@ -559,84 +428,42 @@ public class YAMLFactory extends JsonFactory
     //protected IOContext _createContext(Object srcRef, boolean resourceManaged)
 
     @Override
-    protected YAMLParser _createParser(InputStream in, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
-        Reader r = _createReader(in, null, ctxt);
+    protected YAMLParser _createParser(InputStream in, IOContext ctxt) throws IOException {
+        return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
+                _objectCodec, _createReader(in, null, ctxt));
+    }
+
+    @Override
+    protected YAMLParser _createParser(Reader r, IOContext ctxt) throws IOException {
         return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
                 _objectCodec, r);
     }
 
+    // since 2.4
     @Override
-    protected YAMLParser _createParser(Reader r, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
+    protected YAMLParser _createParser(char[] data, int offset, int len, IOContext ctxt,
+            boolean recyclable) throws IOException {
         return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, r);
+                _objectCodec, new CharArrayReader(data, offset, len));
     }
 
     @Override
-    protected YAMLParser _createParser(byte[] data, int offset, int len, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
-        Reader r = _createReader(data, offset, len, null, ctxt);
+    protected YAMLParser _createParser(byte[] data, int offset, int len, IOContext ctxt) throws IOException {
         return new YAMLParser(ctxt, _getBufferRecycler(), _parserFeatures, _yamlParserFeatures,
-                _objectCodec, r);
+                _objectCodec, _createReader(data, offset, len, null, ctxt));
     }
 
     @Override
-    protected YAMLParser _createJsonParser(InputStream in, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
-        return _createParser(in, ctxt);
-    }
-
-    @Override
-    protected JsonParser _createJsonParser(Reader r, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
-        return _createParser(r, ctxt);
-    }
-
-    @Override
-    protected YAMLParser _createJsonParser(byte[] data, int offset, int len, IOContext ctxt)
-        throws IOException, JsonParseException
-    {
-        return _createParser(data, offset, len, ctxt);
-    }
-
-    @Override
-    protected YAMLGenerator _createGenerator(Writer out, IOContext ctxt)
-        throws IOException
-    {
+    protected YAMLGenerator _createGenerator(Writer out, IOContext ctxt) throws IOException {
         int feats = _yamlGeneratorFeatures;
         YAMLGenerator gen = new YAMLGenerator(ctxt, _generatorFeatures, feats,
-                _objectCodec, out, _outputOptions, _version);
+                _objectCodec, out, _version);
         // any other initializations? No?
         return gen;
     }
-
-    @Override
-    protected YAMLGenerator _createJsonGenerator(Writer out, IOContext ctxt)
-        throws IOException
-    {
-        return _createGenerator(out, ctxt);
-    }
-
-    @Override
-    protected YAMLGenerator _createUTF8Generator(OutputStream out, IOContext ctxt) throws IOException {
-    	return _createGenerator(new UTF8Writer(out), ctxt);
-    }
-
-    @Override
-    @Deprecated
-    protected YAMLGenerator _createUTF8JsonGenerator(OutputStream out, IOContext ctxt) throws IOException {
-        return _createUTF8Generator(out, ctxt);
-    }
     
     @Override
-    protected Writer _createWriter(OutputStream out, JsonEncoding enc, IOContext ctxt) throws IOException
-    {
+    protected Writer _createWriter(OutputStream out, JsonEncoding enc, IOContext ctxt) throws IOException {
         if (enc == JsonEncoding.UTF8) {
             return new UTF8Writer(out);
         }
@@ -658,7 +485,7 @@ public class YAMLFactory extends JsonFactory
         }
         // default to UTF-8 if encoding missing
         if (enc == JsonEncoding.UTF8) {
-            boolean autoClose = ctxt.isResourceManaged() || this.isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE);
+            boolean autoClose = ctxt.isResourceManaged() || isEnabled(JsonParser.Feature.AUTO_CLOSE_SOURCE);
             return new UTF8Reader(in, autoClose);
 //          return new InputStreamReader(in, UTF8);
         }
