@@ -18,11 +18,10 @@ import com.fasterxml.jackson.core.util.ByteArrayBuilder;
 
 /**
  * {@link JsonParser} implementation used to expose YAML documents
- * in form that allows other Jackson functionality to deal
- * with it.
+ * in form that allows other Jackson functionality to process YAML content,
+ * such as binding POJOs to and from it, and building tree representations.
  */
-public class YAMLParser
-    extends ParserBase
+public class YAMLParser extends ParserBase
 {
     /**
      * Enumeration that defines all togglable features for YAML parsers.
@@ -92,9 +91,10 @@ public class YAMLParser
      * Need to keep track of underlying {@link Reader} to be able to
      * auto-close it (if required to)
      */
-    protected Reader _reader;
-    
-    protected ParserImpl _yamlParser;
+    protected final Reader _reader;
+
+    protected final ParserImpl _yamlParser;
+
     /*
     /**********************************************************************
     /* State
@@ -178,8 +178,9 @@ public class YAMLParser
      * Method that can be used to check if the current token has an
      * associated anchor (id to reference via Alias)
      * 
-     * @since 2.1
+     * @deprecated Since 2.3 (was added in 2.1) -- use {@link #getObjectId} instead
      */
+    @Deprecated
     public String getCurrentAnchor() {
         return _currentAnchor;
     }
@@ -201,7 +202,6 @@ public class YAMLParser
     /**********************************************************                              
      */
 
-    
     @Override
     protected boolean loadMore() throws IOException {
         throw new UnsupportedOperationException();
@@ -333,7 +333,6 @@ public class YAMLParser
             if (evt == null) {
                 return (_currToken = null);
             }
-            
             _lastEvent = evt;
             
             /* One complication: field names are only inferred from the
@@ -362,13 +361,16 @@ public class YAMLParser
 
             // scalar values are probably the commonest:
             if (evt.is(Event.ID.Scalar)) {
-                return (_currToken = _decodeScalar((ScalarEvent) evt));
+                JsonToken t = _decodeScalar((ScalarEvent) evt);
+                _currToken = t;
+                return t;
             }
 
             // followed by maps, then arrays
             if (evt.is(Event.ID.MappingStart)) {
                 Mark m = evt.getStartMark();
-                _currentAnchor = ((NodeEvent)evt).getAnchor();
+                MappingStartEvent map = (MappingStartEvent) evt;
+                _currentAnchor = map.getAnchor();
                 _parsingContext = _parsingContext.createChildObjectContext(m.getLine(), m.getColumn());
                 return (_currToken = JsonToken.START_OBJECT);
             }
@@ -397,6 +399,7 @@ public class YAMLParser
                 return (_currToken = null);
             }
             if (evt.is(Event.ID.DocumentStart)) {
+//                DocumentStartEvent dd = (DocumentStartEvent) evt;
                 // does this matter? Shouldn't, should it?
                 continue;
             }
@@ -616,6 +619,7 @@ public class YAMLParser
         return null;
     }
     
+    @SuppressWarnings("resource")
     @Override
     public byte[] getBinaryValue(Base64Variant variant) throws IOException, JsonParseException
     {
@@ -711,6 +715,52 @@ public class YAMLParser
         _reportError("Current token ("+_currToken+") not numeric, can not use numeric value accessors");
     }
 
+    /*
+    /**********************************************************************
+    /* Native id (type id) access
+    /**********************************************************************
+     */
+
+    @Override
+    public boolean canReadObjectId() { // yup
+        return true;
+    }
+    
+    @Override
+    public boolean canReadTypeId() {
+        return true; // yes, YAML got 'em
+    }
+    
+    @Override
+    public String getObjectId() throws IOException, JsonGenerationException
+    {
+        return _currentAnchor;
+    }
+
+    @Override
+    public String getTypeId() throws IOException, JsonGenerationException
+    {
+        String tag;
+        if (_lastEvent instanceof CollectionStartEvent) {
+            tag = ((CollectionStartEvent) _lastEvent).getTag();
+        } else if (_lastEvent instanceof ScalarEvent) {
+            tag = ((ScalarEvent) _lastEvent).getTag();
+        } else {
+            return null;
+        }
+        if (tag != null) {
+            /* 04-Aug-2013, tatu: Looks like YAML parser's expose these in...
+             *   somewhat exotic ways sometimes. So let's prepare to peel off
+             *   some wrappings:
+             */
+            while (tag.startsWith("!")) {
+                tag = tag.substring(1);
+            }
+            return tag;
+        }
+        return null;
+    }
+    
     /*
     /**********************************************************************
     /* Internal methods
